@@ -46,7 +46,7 @@ class TreeAnalysis:
               self.save()
         else:
             elements = [element for element in data]
-            batch_size = len(people)/processes
+            batch_size = len(elements)/processes
             batches = [
                 elements[ round(i*batch_size) : round((1+i)*batch_size) ]
                 for i in range(processes)
